Documentation
¶
Index ¶
Constants ¶
const SDKName = "razorpay-go"
SDKName ...Name of this SDK
const SDKVersion = "1.4.0"
SDKVersion ...
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Client ¶
type Client struct {
*requests.Request
Addon *resources.Addon
Account *resources.Account
Card *resources.Card
Customer *resources.Customer
Invoice *resources.Invoice
PaymentLink *resources.PaymentLink
Order *resources.Order
Payment *resources.Payment
Plan *resources.Plan
Product *resources.Product
Refund *resources.Refund
Subscription *resources.Subscription
Token *resources.Token
Transfer *resources.Transfer
VirtualAccount *resources.VirtualAccount
QrCode *resources.QrCode
FundAccount *resources.FundAccount
Settlement *resources.Settlement
Stakeholder *resources.Stakeholder
Item *resources.Item
Iin *resources.Iin
Webhook *resources.Webhook
Document *resources.Document
Dispute *resources.Dispute
Payout *resources.Payout
}
Client provides various helper methods to make HTTP requests to Razorpay's APIs.
func NewClient ¶
NewClient creates and returns a new Razorpay client. key and secret are used to authenticate the requests made to Razorpay's APIs.
func (*Client) AddHeaders ¶
AddHeaders adds additional headers to Razorpay's client. All requests made using the client will contain these additional headers in the HTTP request.
func (*Client) SetTimeout ¶
SetTimeout sets the timeout of Razorpay's Client. The default timeout will be overridden for all HTTP requests made using this client.
func (*Client) SetUserAgent ¶ added in v1.3.4
Click to show internal directories.
Click to hide internal directories.